document.addEventListener('DOMContentLoaded', () => {
  let currentWord = '';
  let words = [];
  let stats = {
    correct: 0,
    total: 0
  };

  const synth = window.speechSynthesis;
  const wordInput = document.getElementById('word-input');
  const playBtn = document.getElementById('play-btn');
  const enterBtn = document.getElementById('enter-btn');
  const hintBtn = document.getElementById('hint-btn');

  // Fetch word list
  fetch('https://www.mit.edu/~ecprice/wordlist.10000')
    .then(response => response.text())
    .then(text => {
      words = text.split('\n').filter(word => word.length > 0);
    });

  function getRandomWord() {
    return words[Math.floor(Math.random() * words.length)];
  }

  function speak(text) {
    const utterance = new SpeechSynthesisUtterance(text);
    synth.speak(utterance);
  }

  function updateStats() {
    document.getElementById('correct-count').textContent = stats.correct;
    document.getElementById('total-count').textContent = stats.total;
    document.getElementById('success-rate').textContent = 
      `${Math.round((stats.correct / stats.total) * 100) || 0}%`;
  }

  function playWord() {
    currentWord = getRandomWord();
    speak(currentWord);
    wordInput.value = '';
  }

  function checkWord() {
    stats.total++;
    if (wordInput.value.toLowerCase() === currentWord.toLowerCase()) {
      stats.correct++;
      speak('Correct!');
      setTimeout(playWord, 1000);
    } else {
      speak('Incorrect. Try again.');
      speak(currentWord);
    }
    updateStats();
  }

  function showHint() {
    const input = wordInput.value.toLowerCase();
    const correct = currentWord.toLowerCase();
    let hintText = '';
    for (let i = 0; i < input.length; i++) {
      if (i >= correct.length || input[i] !== correct[i]) {
        hintText += '❌';
      } else {
        hintText += input[i];
      }
    }
    wordInput.value = hintText;
  }

  // Event Listeners
  playBtn.addEventListener('click', playWord);
  enterBtn.addEventListener('click', checkWord);
  hintBtn.addEventListener('click', showHint);

  // Virtual Keyboard
  document.querySelectorAll('.keyboard button').forEach(button => {
    button.addEventListener('click', () => {
      wordInput.value += button.textContent;
    });
  });

  // Physical Keyboard
  document.addEventListener('keydown', (e) => {
    if (e.key === 'Enter') {
      checkWord();
    } else if (e.key.length === 1 && e.key.match(/[a-z]/i)) {
      wordInput.value += e.key.toUpperCase();
    }
  });

  // Initialize
  playWord();
});